pub struct MatchResult {
pub file: PathBuf,
pub grammar: String,
pub kind: String,
pub text: String,
pub start_row: usize,
pub start_col: usize,
pub end_row: usize,
pub end_col: usize,
pub captures: HashMap<String, String>,
}Expand description
Match result from either pattern type.
Fields
file: PathBufgrammar: Stringkind: Stringtext: Stringstart_row: usizestart_col: usizeend_row: usizeend_col: usizecaptures: HashMap<String, String>Trait Implementations
Sourceimpl Debug for MatchResult
impl Debug for MatchResult
Sourceimpl JsonSchema for MatchResult
impl JsonSchema for MatchResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MatchResult
impl RefUnwindSafe for MatchResult
impl Send for MatchResult
impl Sync for MatchResult
impl Unpin for MatchResult
impl UnsafeUnpin for MatchResult
impl UnwindSafe for MatchResult