pub struct RulesConfig(pub HashMap<String, RuleOverride>);Expand description
Configuration for syntax rules analysis. Maps rule ID to per-rule configuration. e.g., { “rust/unnecessary-let” = { severity = “warning” } }
Tuple Fields
0: HashMap<String, RuleOverride>Trait Implementations
Sourceimpl Clone for RulesConfig
impl Clone for RulesConfig
Sourcefn clone(&self) -> RulesConfig
fn clone(&self) -> RulesConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RulesConfig
impl Debug for RulesConfig
Sourceimpl Default for RulesConfig
impl Default for RulesConfig
Sourcefn default() -> RulesConfig
fn default() -> RulesConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RulesConfig
impl<'de> Deserialize<'de> for RulesConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RulesConfig
impl JsonSchema for RulesConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RulesConfig
impl RefUnwindSafe for RulesConfig
impl Send for RulesConfig
impl Sync for RulesConfig
impl Unpin for RulesConfig
impl UnwindSafe for RulesConfig