pub fn apply_fixes(findings: &[Finding]) -> Result<usize>
Apply fixes to findings, returning the number of files modified. Fixes are applied in reverse order within each file to preserve byte offsets.